Internal-use fork of
include_dir_macros for
trillium.rs. It is not intended for general
use. Credit for the bulk of the code goes to the authors of the
upstream crate.
Differences from upstream:
include_entry was added, which returns a DirEntry instead of a Dir, making direct inclusion of files possible Metadata is always enabled relative paths are resolved from a root of CARGO_MANIFEST_DIR hygiene is maintained by using a macro_rules macro to import relevant structs Optional compile-time precompression of file contents into Brotli / Zstd / Gzip variants, gated behind cargo features.
Macros
- include_
dir - Embed the contents of a directory. “Returns” a Dir
- include_
entry - Embed a directory or file. “Returns” a DirEntry